@@ -6,14 +6,15 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-recomplete
-;; Version: 0.2
+;; Package-Version: 20250913.2251
+;; Package-Revision: 6bf7081c4482
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
 
 ;; This package provides mechanism for immediate completion, running again cycles over options.
 
-;;; Usage:
+;;; Usage
 
 ;;
 ;; A key can be bound to a completion action,
@@ -73,10 +74,10 @@
 ;; - This is set to nil via `recomplete--alist-clear-hook' when incompatible functions run.
 ;;
 ;; Keys are:
-;; - `buffer-undo-list': The buffer-undo-list before execution.
-;; - `pending-undo-list': The pending-undo-list before execution.
+;; - `buffer-undo-list': The undo state before execution.
+;; - `pending-undo-list': The undo state before execution.
 ;; - `point' The point before execution.
-;; - `msg-text' The message text displayed to the user.
+;; - `msg-text' The point before execution.
 ;; - `cycle-index' The position in the list of options to cycle through.
 ;; - `cycle-reverse' when t, reverse the cycle direction.
 ;; - `fn-symbol' The symbol to identify the type of chain being cycled.
@@ -95,7 +96,7 @@
 (defmacro recomplete--with-advice (advice &rest body)
   "Execute BODY with ADVICE temporarily enabled.
 
-Each advice is a triplet of (SYMBOL HOW FUNCTION),
+Advice are triplets of (SYMBOL HOW FUNCTION),
 see `advice-add' documentation."
   (declare (indent 1))
   (let ((advice-list advice)
@@ -177,7 +178,7 @@ see `advice-add' documentation."
 (defun recomplete--undo-next (list)
   "Get the next undo step in LIST.
 
-Argument LIST is a `buffer-undo-list' compatible list."
+Argument LIST compatible list `buffer-undo-list'."
   (declare (important-return-value t))
   (while (car list)
     (setq list (cdr list)))
@@ -204,7 +205,7 @@ Argument LIST is a `buffer-undo-list' compatible list."
    ((eq this-command 'keyboard-quit)
 
     ;; Toggle reverse direction.
-    (let ((cycle-reverse (null (alist-get 'cycle-reverse recomplete--alist))))
+    (let ((cycle-reverse (not (alist-get 'cycle-reverse recomplete--alist))))
 
       ;; Re-display the message.
       (let ((msg-prefix
@@ -242,7 +243,7 @@ Argument FN-CACHE stores the result for reuse."
                 (setq result-choices miss)
                 (setq word-beg (marker-position start))
                 (setq word-end (marker-position end))
-                ;; Return the word that makes the correction; we handle this ourselves next.
+                ;; Return the word would make the correction, we do this ourselves next.
                 nil))))
         (ispell-word))
 
@@ -274,7 +275,7 @@ Argument FN-CACHE stores the result for reuse."
 
         ;; Scan backward over "-_".
         (let ((pos-prev (1+ word-beg)))
-          (while (null (eql pos-prev word-beg))
+          (while (not (eql pos-prev word-beg))
             (setq pos-prev word-beg)
             (when (memq (char-before word-beg) (list ?_ ?-))
               (let ((range
@@ -285,7 +286,7 @@ Argument FN-CACHE stores the result for reuse."
                   (setq word-beg (car range)))))))
         ;; Scan forward over "-_".
         (let ((pos-prev (1- word-end)))
-          (while (null (eql pos-prev word-end))
+          (while (not (eql pos-prev word-end))
             (setq pos-prev word-end)
             (when (memq (char-after word-end) (list ?_ ?-))
               (let ((range
@@ -413,7 +414,7 @@ Argument FN-CACHE stores the result for reuse."
 ;; Implementation: `dabbrev'
 
 (defun recomplete-impl-dabbrev (cycle-index fn-cache)
-  "Expand using `dabbrev' at CYCLE-INDEX.
+  "Cycle case styles using the choice at CYCLE-INDEX.
 Argument FN-CACHE stores the result for reuse."
   (declare (important-return-value t))
   (pcase-let ((`(,result-choices ,word-beg ,word-end) (or fn-cache '(nil nil nil))))
@@ -519,7 +520,7 @@ Return the region replaced."
 
 ;;;###autoload
 (defun recomplete-with-callback (fn-symbol cycle-offset &optional cycle-index-init)
-  "Run FN-SYMBOL, chaining executions for this function.
+  "Run FN-SYMBOL, chaining executions for any function in FN-GROUP.
 
 Argument CYCLE-OFFSET The offset for cycling words,
 1 or -1 for forward/backward.
@@ -561,7 +562,7 @@ step onto the next item)."
       ;;
       ;; While we could check `this-command', this isn't set properly when called indirectly.
       ;; Simply check if the internal symbol changes.
-      (when (and alist (null (eq fn-symbol (alist-get 'fn-symbol alist))))
+      (when (and alist (not (eq fn-symbol (alist-get 'fn-symbol alist))))
         (setq alist nil))
 
       ;; We only need to check if `recomplete--alist' is set here,
@@ -580,7 +581,7 @@ step onto the next item)."
           (setq cycle-offset (- cycle-offset)))
         (setq cycle-index (+ cycle-offset (cdr (assq 'cycle-index alist))))
 
-        ;; Undo with strict checks so we know _exactly_ what's going on
+        ;; Undo with strict checks so we know _exactly_ whats going on
         ;; and don't allow some unknown state to be entered.
         (let ((undo-data (cdr buffer-undo-list)) ; Skip the 'nil' car of the list.
               (undo-data-init (cdr buffer-undo-list-init)))
@@ -590,7 +591,7 @@ step onto the next item)."
           ;; This can happen when `recomplete' cycles back to the initial state.
           ;; While not common it can happen if the complete action compares the state
           ;; of the current buffer with the contents that replaces it, where no change
-          ;; is found and no undo step is added. In this case, the last undo will be skipped.
+          ;; if found and no undo step is added. In this case, the last undo will be skipped.
           (unless (eq undo-data-init undo-data)
             ;; Since setting undo-data could corrupt the buffer if there is an unexpected state,
             ;; ensure we have exactly one undo step added,
@@ -692,7 +693,7 @@ step onto the next item)."
 
                     (unless (zerop msg-start)
                       (setq msg-text (concat ellipsis (substring msg-text (length ellipsis)))))))))
-            ;; Single line display logic has been handled.
+            ;; End single line display.
 
             ;; Run last so we can ensure it's the last text in the message buffer.
             ;; Don't log because it's not useful to keep the selection.
@@ -712,7 +713,7 @@ step onto the next item)."
                    (cons 'is-first-post-command t)
                    (cons 'msg-text msg-text)))
 
-            ;; Ensure a local hook, which removes itself on the first non-successive call
+            ;; Ensure a local hook, which removes it's self on the first non-successive call
             ;; to a command that doesn't execute `recomplete-with-callback' with `fn-symbol'.
             (add-hook 'post-command-hook #'recomplete--alist-clear-hook 0 t)))
 
